/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */

/* THIS FILE IS AUTOGENERATED! */
#ifndef __LOCAL_STORAGE_SKEL_H__
#define __LOCAL_STORAGE_SKEL_H__

#include <errno.h>
#include <stdlib.h>
#include <bpf/libbpf.h>

struct local_storage {
	struct bpf_object_skeleton *skeleton;
	struct bpf_object *obj;
	struct {
		struct bpf_map *inode_storage_map;
		struct bpf_map *sk_storage_map;
		struct bpf_map *task_storage_map;
		struct bpf_map *bss;
		struct bpf_map *data;
	} maps;
	struct {
		struct bpf_program *unlink_hook;
		struct bpf_program *inode_rename;
		struct bpf_program *socket_bind;
		struct bpf_program *socket_post_create;
		struct bpf_program *exec;
	} progs;
	struct {
		struct bpf_link *unlink_hook;
		struct bpf_link *inode_rename;
		struct bpf_link *socket_bind;
		struct bpf_link *socket_post_create;
		struct bpf_link *exec;
	} links;
	struct local_storage__bss {
		int monitored_pid;
	} *bss;
	struct local_storage__data {
		int inode_storage_result;
		int sk_storage_result;
	} *data;
};

static void
local_storage__destroy(struct local_storage *obj)
{
	if (!obj)
		return;
	if (obj->skeleton)
		bpf_object__destroy_skeleton(obj->skeleton);
	free(obj);
}

static inline int
local_storage__create_skeleton(struct local_storage *obj);

static inline struct local_storage *
local_storage__open_opts(const struct bpf_object_open_opts *opts)
{
	struct local_storage *obj;
	int err;

	obj = (struct local_storage *)calloc(1, sizeof(*obj));
	if (!obj) {
		errno = ENOMEM;
		return NULL;
	}

	err = local_storage__create_skeleton(obj);
	if (err)
		goto err_out;

	err = bpf_object__open_skeleton(obj->skeleton, opts);
	if (err)
		goto err_out;

	return obj;
err_out:
	local_storage__destroy(obj);
	errno = -err;
	return NULL;
}

static inline struct local_storage *
local_storage__open(void)
{
	return local_storage__open_opts(NULL);
}

static inline int
local_storage__load(struct local_storage *obj)
{
	return bpf_object__load_skeleton(obj->skeleton);
}

static inline struct local_storage *
local_storage__open_and_load(void)
{
	struct local_storage *obj;
	int err;

	obj = local_storage__open();
	if (!obj)
		return NULL;
	err = local_storage__load(obj);
	if (err) {
		local_storage__destroy(obj);
		errno = -err;
		return NULL;
	}
	return obj;
}

static inline int
local_storage__attach(struct local_storage *obj)
{
	return bpf_object__attach_skeleton(obj->skeleton);
}

static inline void
local_storage__detach(struct local_storage *obj)
{
	return bpf_object__detach_skeleton(obj->skeleton);
}

static inline const void *local_storage__elf_bytes(size_t *sz);

static inline int
local_storage__create_skeleton(struct local_storage *obj)
{
	struct bpf_object_skeleton *s;

	s = (struct bpf_object_skeleton *)calloc(1, sizeof(*s));
	if (!s)
		goto err;
	obj->skeleton = s;

	s->sz = sizeof(*s);
	s->name = "local_storage";
	s->obj = &obj->obj;

	/* maps */
	s->map_cnt = 5;
	s->map_skel_sz = sizeof(*s->maps);
	s->maps = (struct bpf_map_skeleton *)calloc(s->map_cnt, s->map_skel_sz);
	if (!s->maps)
		goto err;

	s->maps[0].name = "inode_storage_map";
	s->maps[0].map = &obj->maps.inode_storage_map;

	s->maps[1].name = "sk_storage_map";
	s->maps[1].map = &obj->maps.sk_storage_map;

	s->maps[2].name = "task_storage_map";
	s->maps[2].map = &obj->maps.task_storage_map;

	s->maps[3].name = "local_st.bss";
	s->maps[3].map = &obj->maps.bss;
	s->maps[3].mmaped = (void **)&obj->bss;

	s->maps[4].name = "local_st.data";
	s->maps[4].map = &obj->maps.data;
	s->maps[4].mmaped = (void **)&obj->data;

	/* programs */
	s->prog_cnt = 5;
	s->prog_skel_sz = sizeof(*s->progs);
	s->progs = (struct bpf_prog_skeleton *)calloc(s->prog_cnt, s->prog_skel_sz);
	if (!s->progs)
		goto err;

	s->progs[0].name = "unlink_hook";
	s->progs[0].prog = &obj->progs.unlink_hook;
	s->progs[0].link = &obj->links.unlink_hook;

	s->progs[1].name = "inode_rename";
	s->progs[1].prog = &obj->progs.inode_rename;
	s->progs[1].link = &obj->links.inode_rename;

	s->progs[2].name = "socket_bind";
	s->progs[2].prog = &obj->progs.socket_bind;
	s->progs[2].link = &obj->links.socket_bind;

	s->progs[3].name = "socket_post_create";
	s->progs[3].prog = &obj->progs.socket_post_create;
	s->progs[3].link = &obj->links.socket_post_create;

	s->progs[4].name = "exec";
	s->progs[4].prog = &obj->progs.exec;
	s->progs[4].link = &obj->links.exec;

	s->data = (void *)local_storage__elf_bytes(&s->data_sz);

	return 0;
err:
	bpf_object__destroy_skeleton(s);
	return -ENOMEM;
}

static inline const void *local_storage__elf_bytes(size_t *sz)
{
	*sz = 13752;
	return (const void *)"\
\x7f\x45\x4c\x46\x02\x01\x01\0\0\0\0\0\0\0\0\0\x01\0\xf7\0\x01\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\xf8\x30\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\x40\0\x13\0\
\x01\0\0\x2e\x73\x74\x72\x74\x61\x62\0\x2e\x73\x79\x6d\x74\x61\x62\0\x6c\x73\
\x6d\x2f\x69\x6e\x6f\x64\x65\x5f\x75\x6e\x6c\x69\x6e\x6b\0\x6c\x73\x6d\x2e\x73\
\x2f\x69\x6e\x6f\x64\x65\x5f\x72\x65\x6e\x61\x6d\x65\0\x6c\x73\x6d\x2e\x73\x2f\
\x73\x6f\x63\x6b\x65\x74\x5f\x62\x69\x6e\x64\0\x6c\x73\x6d\x2e\x73\x2f\x73\x6f\
\x63\x6b\x65\x74\x5f\x70\x6f\x73\x74\x5f\x63\x72\x65\x61\x74\x65\0\x6c\x73\x6d\
\x2e\x73\x2f\x62\x70\x72\x6d\x5f\x63\x6f\x6d\x6d\x69\x74\x74\x65\x64\x5f\x63\
\x72\x65\x64\x73\0\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x62\x73\x73\0\x2e\x64\x61\
\x74\x61\0\x2e\x6d\x61\x70\x73\0\x6c\x6f\x63\x61\x6c\x5f\x73\x74\x6f\x72\x61\
\x67\x65\x2e\x63\0\x4c\x42\x42\x30\x5f\x34\0\x4c\x42\x42\x30\x5f\x33\0\x4c\x42\
\x42\x31\x5f\x35\0\x4c\x42\x42\x31\x5f\x33\0\x4c\x42\x42\x32\x5f\x36\0\x4c\x42\
\x42\x32\x5f\x34\0\x4c\x42\x42\x33\x5f\x33\0\x4c\x42\x42\x34\x5f\x36\0\x4c\x42\
\x42\x34\x5f\x33\0\x4c\x42\x42\x34\x5f\x34\0\x75\x6e\x6c\x69\x6e\x6b\x5f\x68\
\x6f\x6f\x6b\0\x6d\x6f\x6e\x69\x74\x6f\x72\x65\x64\x5f\x70\x69\x64\0\x74\x61\
\x73\x6b\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x6d\x61\x70\0\x69\x6e\x6f\x64\x65\
\x5f\x72\x65\x6e\x61\x6d\x65\0\x69\x6e\x6f\x64\x65\x5f\x73\x74\x6f\x72\x61\x67\
\x65\x5f\x6d\x61\x70\0\x69\x6e\x6f\x64\x65\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\
\x72\x65\x73\x75\x6c\x74\0\x73\x6f\x63\x6b\x65\x74\x5f\x62\x69\x6e\x64\0\x73\
\x6b\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x6d\x61\x70\0\x73\x6b\x5f\x73\x74\x6f\
\x72\x61\x67\x65\x5f\x72\x65\x73\x75\x6c\x74\0\x73\x6f\x63\x6b\x65\x74\x5f\x70\
\x6f\x73\x74\x5f\x63\x72\x65\x61\x74\x65\0\x65\x78\x65\x63\0\x5f\x6c\x69\x63\
\x65\x6e\x73\x65\0\x2e\x72\x65\x6c\x6c\x73\x6d\x2f\x69\x6e\x6f\x64\x65\x5f\x75\
\x6e\x6c\x69\x6e\x6b\0\x2e\x72\x65\x6c\x6c\x73\x6d\x2e\x73\x2f\x69\x6e\x6f\x64\
\x65\x5f\x72\x65\x6e\x61\x6d\x65\0\x2e\x72\x65\x6c\x6c\x73\x6d\x2e\x73\x2f\x73\
\x6f\x63\x6b\x65\x74\x5f\x62\x69\x6e\x64\0\x2e\x72\x65\x6c\x6c\x73\x6d\x2e\x73\
\x2f\x73\x6f\x63\x6b\x65\x74\x5f\x70\x6f\x73\x74\x5f\x63\x72\x65\x61\x74\x65\0\
\x2e\x72\x65\x6c\x6c\x73\x6d\x2e\x73\x2f\x62\x70\x72\x6d\x5f\x63\x6f\x6d\x6d\
\x69\x74\x74\x65\x64\x5f\x63\x72\x65\x64\x73\0\x2e\x42\x54\x46\0\x2e\x42\x54\
\x46\x2e\x65\x78\x74\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\x94\0\0\0\x04\0\xf1\xff\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x03\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xa4\0\0\0\0\0\x03\0\xa8\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\xab\0\0\0\0\0\x03\0\xa0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\
\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb2\0\0\0\0\0\x04\0\xf8\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\xb9\0\0\0\0\0\x04\0\xb0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x03\0\x05\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xc0\0\0\0\0\0\x05\0\xe8\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\xc7\0\0\0\0\0\x05\0\xa0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x03\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xce\0\0\0\0\0\x06\0\x80\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x07\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\xd5\0\0\0\0\0\x07\0\xe8\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xdc\0\0\0\0\0\x07\0\x80\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xe3\0\0\0\0\0\x07\0\x98\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\xea\0\0\0\x12\0\x03\0\0\0\0\0\0\0\0\0\xb8\0\0\0\0\0\0\0\xf6\0\0\0\x11\0\
\x09\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\x04\x01\0\0\x11\0\x0b\0\x40\0\0\0\0\0\
\0\0\x20\0\0\0\0\0\0\0\x15\x01\0\0\x12\0\x04\0\0\0\0\0\0\0\0\0\x08\x01\0\0\0\0\
\0\0\x22\x01\0\0\x11\0\x0b\0\0\0\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\x34\x01\0\0\x11\
\0\x0a\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\x49\x01\0\0\x12\0\x05\0\0\0\0\0\0\0\
\0\0\xf8\0\0\0\0\0\0\0\x55\x01\0\0\x11\0\x0b\0\x20\0\0\0\0\0\0\0\x20\0\0\0\0\0\
\0\0\x64\x01\0\0\x11\0\x0a\0\x04\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\x76\x01\0\0\
\x12\0\x06\0\0\0\0\0\0\0\0\0\x90\0\0\0\0\0\0\0\x89\x01\0\0\x12\0\x07\0\0\0\0\0\
\0\0\0\0\xf0\0\0\0\0\0\0\0\x8e\x01\0\0\x11\0\x08\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\
\0\0\0\xb4\x06\0\0\0\0\0\0\x79\x17\x08\0\0\0\0\0\x85\0\0\0\x0e\0\0\0\x18\x01\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x61\x11\0\0\0\0\0\0\x77\0\0\0\x20\0\0\0\x5e\x01\x0d\
\0\0\0\0\0\x85\0\0\0\x9e\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xbf\x02\0\0\
\0\0\0\0\xb7\x03\0\0\0\0\0\0\xb7\x04\0\0\0\0\0\0\x85\0\0\0\x9c\0\0\0\x15\0\x04\
\0\0\0\0\0\xb4\x06\0\0\xff\xff\xff\xff\x79\x71\x30\0\0\0\0\0\x79\x02\0\0\0\0\0\
\0\x1d\x12\x01\0\0\0\0\0\xb4\x06\0\0\0\0\0\0\xbc\x60\0\0\0\0\0\0\x95\0\0\0\0\0\
\0\0\x79\x16\x08\0\0\0\0\0\x79\x17\x18\0\0\0\0\0\x85\0\0\0\x0e\0\0\0\x79\x72\
\x30\0\0\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\x03\0\0\0\0\0\0\xb7\x04\
\0\0\x01\0\0\0\x85\0\0\0\x91\0\0\0\x79\x62\x30\0\0\0\0\0\x18\x01\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\xb7\x03\0\0\0\0\0\0\xb7\x04\0\0\0\0\0\0\x85\0\0\0\x91\0\0\0\x15\
\0\x0f\0\0\0\0\0\x61\x01\x08\0\0\0\0\0\x16\x01\x04\0\xef\xbe\xad\xde\x18\x01\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\xb4\x02\0\0\xff\xff\xff\xff\x63\x21\0\0\0\0\0\0\x79\
\x62\x30\0\0\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x85\0\0\0\x92\0\0\0\x56\
\0\x04\0\0\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb4\x02\0\0\0\0\0\0\x63\
\x21\0\0\0\0\0\0\xb4\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\x79\x16\0\0\0\0\0\0\x85\0\
\0\0\x0e\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x61\x11\0\0\0\0\0\0\x77\0\0\
\0\x20\0\0\0\x5e\x01\x16\0\0\0\0\0\x79\x62\x18\0\0\0\0\0\x18\x01\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\xb7\x03\0\0\0\0\0\0\xb7\x04\0\0\x01\0\0\0\x85\0\0\0\x6b\0\0\0\
\x15\0\x0f\0\0\0\0\0\x61\x01\x08\0\0\0\0\0\x16\x01\x04\0\xef\xbe\xad\xde\x18\
\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb4\x02\0\0\xff\xff\xff\xff\x63\x21\0\0\0\0\0\
\0\x79\x62\x18\0\0\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x85\0\0\0\x6c\0\0\
\0\x56\0\x04\0\0\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb4\x02\0\0\0\0\0\0\
\x63\x21\0\0\0\0\0\0\xb4\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\x79\x16\0\0\0\0\0\0\
\x85\0\0\0\x0e\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x61\x11\0\0\0\0\0\0\
\x77\0\0\0\x20\0\0\0\x5e\x01\x09\0\0\0\0\0\x79\x62\x18\0\0\0\0\0\x18\x01\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\xb7\x03\0\0\0\0\0\0\xb7\x04\0\0\x01\0\0\0\x85\0\0\0\x6b\
\0\0\0\x15\0\x02\0\0\0\0\0\xb4\x01\0\0\xef\xbe\xad\xde\x63\x10\x08\0\0\0\0\0\
\xb4\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\x79\x16\0\0\0\0\0\0\x85\0\0\0\x0e\0\0\0\
\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x61\x11\0\0\0\0\0\0\x77\0\0\0\x20\0\0\0\
\x5e\x01\x16\0\0\0\0\0\x85\0\0\0\x9e\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\xbf\x02\0\0\0\0\0\0\xb7\x03\0\0\0\0\0\0\xb7\x04\0\0\x01\0\0\0\x85\0\0\0\x9c\0\
\0\0\x55\0\x01\0\0\0\0\0\x05\0\x03\0\0\0\0\0\x79\x61\x40\0\0\0\0\0\x79\x11\x20\
\0\0\0\0\0\x7b\x10\0\0\0\0\0\0\x79\x61\x40\0\0\0\0\0\x79\x12\x20\0\0\0\0\0\x18\
\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\x03\0\0\0\0\0\0\xb7\x04\0\0\x01\0\0\0\x85\
\0\0\0\x91\0\0\0\x15\0\x02\0\0\0\0\0\xb4\x01\0\0\xef\xbe\xad\xde\x63\x10\x08\0\
\0\0\0\0\x95\0\0\0\0\0\0\0\x47\x50\x4c\0\xff\xff\xff\xff\xff\xff\xff\xff\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x18\0\0\0\0\0\0\0\x01\0\0\0\x12\0\0\0\
\x48\0\0\0\0\0\0\0\x01\0\0\0\x13\0\0\0\x20\0\0\0\0\0\0\0\x01\0\0\0\x15\0\0\0\
\x50\0\0\0\0\0\0\0\x01\0\0\0\x15\0\0\0\x90\0\0\0\0\0\0\0\x01\0\0\0\x16\0\0\0\
\xb8\0\0\0\0\0\0\0\x01\0\0\0\x15\0\0\0\xd8\0\0\0\0\0\0\0\x01\0\0\0\x16\0\0\0\
\x10\0\0\0\0\0\0\0\x01\0\0\0\x12\0\0\0\x40\0\0\0\0\0\0\0\x01\0\0\0\x18\0\0\0\
\x80\0\0\0\0\0\0\0\x01\0\0\0\x19\0\0\0\xa8\0\0\0\0\0\0\0\x01\0\0\0\x18\0\0\0\
\xc8\0\0\0\0\0\0\0\x01\0\0\0\x19\0\0\0\x10\0\0\0\0\0\0\0\x01\0\0\0\x12\0\0\0\
\x40\0\0\0\0\0\0\0\x01\0\0\0\x18\0\0\0\x10\0\0\0\0\0\0\0\x01\0\0\0\x12\0\0\0\
\x40\0\0\0\0\0\0\0\x01\0\0\0\x13\0\0\0\xa8\0\0\0\0\0\0\0\x01\0\0\0\x15\0\0\0\
\x9f\xeb\x01\0\x18\0\0\0\0\0\0\0\x50\x11\0\0\x50\x11\0\0\xc6\x0e\0\0\0\0\0\0\0\
\0\0\x02\x03\0\0\0\x01\0\0\0\0\0\0\x01\x04\0\0\0\x20\0\0\x01\0\0\0\0\0\0\0\x03\
\0\0\0\0\x02\0\0\0\x04\0\0\0\x1c\0\0\0\x05\0\0\0\0\0\0\x01\x04\0\0\0\x20\0\0\0\
\0\0\0\0\0\0\0\x02\x06\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x02\0\0\0\x04\0\0\0\x01\
\0\0\0\0\0\0\0\0\0\0\x02\x02\0\0\0\0\0\0\0\0\0\0\x02\x09\0\0\0\x19\0\0\0\x02\0\
\0\x04\x10\0\0\0\x27\0\0\0\x0a\0\0\0\0\0\0\0\x32\0\0\0\x0b\0\0\0\x40\0\0\0\0\0\
\0\0\0\0\0\x02\xa3\0\0\0\x38\0\0\0\0\0\0\x08\x0c\0\0\0\x3e\0\0\0\0\0\0\x01\x04\
\0\0\0\x20\0\0\0\0\0\0\0\x04\0\0\x04\x20\0\0\0\x4b\0\0\0\x01\0\0\0\0\0\0\0\x50\
\0\0\0\x05\0\0\0\x40\0\0\0\x5a\0\0\0\x07\0\0\0\x80\0\0\0\x32\0\0\0\x08\0\0\0\
\xc0\0\0\0\x5e\0\0\0\0\0\0\x0e\x0d\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\x02\x10\0\0\0\
\0\0\0\0\0\0\0\x03\0\0\0\0\x02\0\0\0\x04\0\0\0\x18\0\0\0\0\0\0\0\0\0\0\x02\x12\
\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x02\0\0\0\x04\0\0\0\x01\x02\0\0\0\0\0\0\x04\0\
\0\x04\x20\0\0\0\x4b\0\0\0\x0f\0\0\0\0\0\0\0\x50\0\0\0\x11\0\0\0\x40\0\0\0\x5a\
\0\0\0\x07\0\0\0\x80\0\0\0\x32\0\0\0\x08\0\0\0\xc0\0\0\0\x70\0\0\0\0\0\0\x0e\
\x13\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\x02\x16\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x02\
\0\0\0\x04\0\0\0\x1d\0\0\0\0\0\0\0\x04\0\0\x04\x20\0\0\0\x4b\0\0\0\x15\0\0\0\0\
\0\0\0\x50\0\0\0\x05\0\0\0\x40\0\0\0\x5a\0\0\0\x07\0\0\0\x80\0\0\0\x32\0\0\0\
\x08\0\0\0\xc0\0\0\0\x7f\0\0\0\0\0\0\x0e\x17\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\x02\
\x1a\0\0\0\x90\0\0\0\0\0\0\x01\x08\0\0\0\x40\0\0\0\0\0\0\0\x01\0\0\x0d\x02\0\0\
\0\xa3\0\0\0\x19\0\0\0\xa7\0\0\0\x01\0\0\x0c\x1b\0\0\0\xb3\0\0\0\x10\0\0\x04\
\xc0\0\0\0\xba\0\0\0\x0c\0\0\0\0\0\0\0\xc2\0\0\0\x1e\0\0\0\x20\0\0\0\xc8\0\0\0\
\x22\0\0\0\x40\0\0\0\xcf\0\0\0\x25\0\0\0\xc0\0\0\0\xd8\0\0\0\x26\0\0\0\0\x01\0\
\0\xdf\0\0\0\x0a\0\0\0\x80\x01\0\0\xe7\0\0\0\x2f\0\0\0\xc0\x01\0\0\xef\0\0\0\
\x30\0\0\0\xc0\x02\0\0\xf9\0\0\0\x43\0\0\0\0\x03\0\0\xfe\0\0\0\x45\0\0\0\x40\
\x03\0\0\x03\x01\0\0\x46\0\0\0\x80\x03\0\0\x0a\x01\0\0\x47\0\0\0\xc0\x03\0\0\0\
\0\0\0\x48\0\0\0\0\x04\0\0\x13\x01\0\0\x49\0\0\0\x80\x04\0\0\x1b\x01\0\0\x49\0\
\0\0\0\x05\0\0\x25\x01\0\0\x4d\0\0\0\x80\x05\0\0\x29\x01\0\0\0\0\0\x08\x1f\0\0\
\0\x3d\x01\0\0\x01\0\0\x04\x04\0\0\0\x4f\x01\0\0\x20\0\0\0\0\0\0\0\x58\x01\0\0\
\0\0\0\x08\x21\0\0\0\x4f\x01\0\0\x01\0\0\x04\x04\0\0\0\x63\x01\0\0\x0c\0\0\0\0\
\0\0\0\x6c\x01\0\0\x02\0\0\x04\x10\0\0\0\x7a\x01\0\0\x23\0\0\0\0\0\0\0\x7f\x01\
\0\0\x24\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\x02\x22\0\0\0\0\0\0\0\0\0\0\x02\x23\0\0\
\0\0\0\0\0\0\0\0\x02\x1d\0\0\0\x85\x01\0\0\x02\0\0\x04\x10\0\0\0\0\0\0\0\x27\0\
\0\0\0\0\0\0\x8a\x01\0\0\x2c\0\0\0\x40\0\0\0\0\0\0\0\x02\0\0\x05\x08\0\0\0\0\0\
\0\0\x28\0\0\0\0\0\0\0\x8f\x01\0\0\x2a\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\x04\x08\0\
\0\0\x98\x01\0\0\x29\0\0\0\0\0\0\0\x9d\x01\0\0\x29\0\0\0\x20\0\0\0\xa1\x01\0\0\
\0\0\0\x08\x0b\0\0\0\xa5\x01\0\0\0\0\0\x08\x2b\0\0\0\xa9\x01\0\0\0\0\0\x08\x1a\
\0\0\0\0\0\0\0\0\0\0\x02\x2d\0\0\0\0\0\0\0\0\0\0\x0a\x2e\0\0\0\xaf\x01\0\0\0\0\
\0\x01\x01\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x2e\0\0\0\x04\0\0\0\x20\0\
\0\0\xbd\x01\0\0\x01\0\0\x04\x08\0\0\0\0\0\0\0\x31\0\0\0\0\0\0\0\0\0\0\0\x02\0\
\0\x05\x08\0\0\0\xc5\x01\0\0\x2b\0\0\0\0\0\0\0\0\0\0\0\x32\0\0\0\0\0\0\0\0\0\0\
\0\x02\0\0\x04\x08\0\0\0\xd0\x01\0\0\x33\0\0\0\0\0\0\0\xd5\x01\0\0\x02\0\0\0\
\x20\0\0\0\xdb\x01\0\0\0\0\0\x08\x34\0\0\0\xe6\x01\0\0\x01\0\0\x04\x04\0\0\0\0\
\0\0\0\x35\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\x05\x04\0\0\0\xef\x01\0\0\x36\0\0\0\0\
\0\0\0\xf5\x01\0\0\x01\0\0\x04\x04\0\0\0\x02\x02\0\0\x37\0\0\0\0\0\0\0\x0b\x02\
\0\0\0\0\0\x08\x38\0\0\0\x1b\x02\0\0\x01\0\0\x04\x04\0\0\0\0\0\0\0\x39\0\0\0\0\
\0\0\0\0\0\0\0\x03\0\0\x05\x04\0\0\0\x25\x02\0\0\x3a\0\0\0\0\0\0\0\0\0\0\0\x3c\
\0\0\0\0\0\0\0\0\0\0\0\x3f\0\0\0\0\0\0\0\x29\x02\0\0\0\0\0\x08\x3b\0\0\0\0\0\0\
\0\x01\0\0\x04\x04\0\0\0\x32\x02\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\x04\x02\
\0\0\0\x3a\x02\0\0\x3d\0\0\0\0\0\0\0\x41\x02\0\0\x3d\0\0\0\x08\0\0\0\x49\x02\0\
\0\0\0\0\x08\x3e\0\0\0\x4c\x02\0\0\0\0\0\x08\x2e\0\0\0\0\0\0\0\x02\0\0\x04\x04\
\0\0\0\x51\x02\0\0\x40\0\0\0\0\0\0\0\x60\x02\0\0\x40\0\0\0\x10\0\0\0\x65\x02\0\
\0\0\0\0\x08\x41\0\0\0\x69\x02\0\0\0\0\0\x08\x42\0\0\0\x6f\x02\0\0\0\0\0\x01\
\x02\0\0\0\x10\0\0\0\0\0\0\0\0\0\0\x02\x44\0\0\0\0\0\0\0\0\0\0\x0a\x9f\0\0\0\0\
\0\0\0\0\0\0\x02\xa8\0\0\0\x7e\x02\0\0\0\0\0\x01\x08\0\0\0\x40\0\0\0\0\0\0\0\0\
\0\0\x02\0\0\0\0\0\0\0\0\x02\0\0\x05\x10\0\0\0\x8c\x02\0\0\x49\0\0\0\0\0\0\0\
\x92\x02\0\0\x4b\0\0\0\0\0\0\0\x99\x02\0\0\x02\0\0\x04\x10\0\0\0\x7a\x01\0\0\
\x4a\0\0\0\0\0\0\0\xa3\x02\0\0\x4a\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\x02\x49\0\0\0\
\0\0\0\0\0\0\0\x02\x4c\0\0\0\xa8\x02\0\0\0\0\0\x08\x60\0\0\0\0\0\0\0\x03\0\0\
\x05\x10\0\0\0\xba\x02\0\0\x4e\0\0\0\0\0\0\0\xc2\x02\0\0\x22\0\0\0\0\0\0\0\xd3\
\x02\0\0\x51\0\0\0\0\0\0\0\xd9\x02\0\0\x02\0\0\x04\x10\0\0\0\x7a\x01\0\0\x4f\0\
\0\0\0\0\0\0\x7f\x01\0\0\x50\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\x02\x4e\0\0\0\0\0\0\
\0\0\0\0\x02\x4f\0\0\0\xe4\x02\0\0\x02\0\0\x04\x10\0\0\0\x7a\x01\0\0\x52\0\0\0\
\0\0\0\0\xf2\x02\0\0\x53\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\x02\x51\0\0\0\0\0\0\0\0\
\0\0\x02\x54\0\0\0\0\0\0\0\x01\0\0\x0d\0\0\0\0\0\0\0\0\x52\0\0\0\xf7\x02\0\0\
\x01\0\0\x0c\x1b\0\0\0\x04\x03\0\0\x01\0\0\x0c\x1b\0\0\0\x10\x03\0\0\x07\0\0\
\x04\x80\0\0\0\x17\x03\0\0\x58\0\0\0\0\0\0\0\x4b\0\0\0\x5a\0\0\0\x20\0\0\0\x1d\
\x03\0\0\x46\0\0\0\x40\0\0\0\x23\x03\0\0\x5b\0\0\0\x80\0\0\0\x28\x03\0\0\x5c\0\
\0\0\xc0\0\0\0\x2b\x03\0\0\x5d\0\0\0\0\x01\0\0\x2f\x03\0\0\x5f\0\0\0\0\x02\0\0\
\x32\x03\0\0\0\0\0\x08\x59\0\0\0\0\0\0\0\x05\0\0\x06\x04\0\0\0\x3f\x03\0\0\0\0\
\0\0\x47\x03\0\0\x01\0\0\0\x56\x03\0\0\x02\0\0\0\x64\x03\0\0\x03\0\0\0\x71\x03\
\0\0\x04\0\0\0\x82\x03\0\0\0\0\0\x01\x02\0\0\0\x10\0\0\x01\0\0\0\0\0\0\0\x02\
\x6f\0\0\0\0\0\0\0\0\0\0\x02\xa7\0\0\0\0\0\0\0\0\0\0\x02\x5e\0\0\0\0\0\0\0\0\0\
\0\x0a\xa6\0\0\0\x88\x03\0\0\x04\0\0\x04\x40\0\0\0\x92\x03\0\0\x4c\0\0\0\0\0\0\
\0\x97\x03\0\0\x61\0\0\0\xc0\0\0\0\x1d\x03\0\0\x46\0\0\0\0\x01\0\0\xa3\x03\0\0\
\x51\0\0\0\x40\x01\0\0\xa7\x03\0\0\x02\0\0\x04\x18\0\0\0\xd0\x01\0\0\x33\0\0\0\
\0\0\0\0\xb7\x03\0\0\x49\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\x02\xa0\0\0\0\xbc\x03\0\
\0\x01\0\0\x0c\x1b\0\0\0\0\0\0\0\x01\0\0\x0d\0\0\0\0\xa3\0\0\0\x19\0\0\0\xcf\
\x03\0\0\x01\0\0\x0c\x63\0\0\0\xd4\x03\0\0\x1a\0\0\x84\xa0\x01\0\0\xe1\x03\0\0\
\x66\0\0\0\0\0\0\0\xe5\x03\0\0\x46\0\0\0\x40\0\0\0\xef\x03\0\0\x67\0\0\0\x80\0\
\0\0\xf2\x03\0\0\x46\0\0\0\xc0\0\0\0\xf4\x03\0\0\x46\0\0\0\0\x01\0\0\xfb\x03\0\
\0\x0c\0\0\0\x40\x01\0\x01\x07\x04\0\0\x0c\0\0\0\x41\x01\0\x01\x14\x04\0\0\x0c\
\0\0\0\x42\x01\0\x01\x1f\x04\0\0\x0c\0\0\0\x43\x01\0\x01\x32\x04\0\0\x5b\0\0\0\
\x80\x01\0\0\x3d\x04\0\0\x5b\0\0\0\xc0\x01\0\0\x23\x03\0\0\x5b\0\0\0\0\x02\0\0\
\x49\x04\0\0\x68\0\0\0\x40\x02\0\0\x4e\x04\0\0\x02\0\0\0\x80\x02\0\0\x55\x04\0\
\0\x0c\0\0\0\xa0\x02\0\0\x5f\x04\0\0\x02\0\0\0\xc0\x02\0\0\x64\x04\0\0\x02\0\0\
\0\xe0\x02\0\0\x69\x04\0\0\x69\0\0\0\0\x03\0\0\x72\x04\0\0\x69\0\0\0\x40\x03\0\
\0\x79\x04\0\0\x69\0\0\0\x80\x03\0\0\x80\x04\0\0\x0c\0\0\0\xc0\x03\0\0\x8d\x04\
\0\0\x02\0\0\0\xe0\x03\0\0\x94\x04\0\0\x46\0\0\0\0\x04\0\0\xcf\x03\0\0\x46\0\0\
\0\x40\x04\0\0\x9b\x04\0\0\x6c\0\0\0\x80\x04\0\0\xa6\x04\0\0\x6e\0\0\0\0\x05\0\
\0\0\0\0\0\0\0\0\x02\xaa\0\0\0\0\0\0\0\0\0\0\x02\xa4\0\0\0\0\0\0\0\0\0\0\x02\
\x9e\0\0\0\0\0\0\0\0\0\0\x02\x6a\0\0\0\0\0\0\0\0\0\0\x0a\x6b\0\0\0\xaa\x04\0\0\
\0\0\0\x01\x01\0\0\0\x08\0\0\x01\xaf\x04\0\0\x02\0\0\x04\x10\0\0\0\xb6\x04\0\0\
\x6d\0\0\0\0\0\0\0\xbf\x04\0\0\x6d\0\0\0\x40\0\0\0\xc8\x04\0\0\0\0\0\x08\x46\0\
\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x6b\0\0\0\x04\0\0\0\0\x01\0\0\x23\x03\0\0\x15\0\
\0\x04\xe8\0\0\0\xd9\x04\0\0\x70\0\0\0\0\0\0\0\xdd\x04\0\0\x73\0\0\0\x80\0\0\0\
\xe4\x04\0\0\x0a\0\0\0\0\x01\0\0\xec\x04\0\0\x75\0\0\0\x40\x01\0\0\xf1\x04\0\0\
\x33\0\0\0\x80\x01\0\0\xf8\x04\0\0\x77\0\0\0\xa0\x01\0\0\x05\x05\0\0\x78\0\0\0\
\xc0\x01\0\0\x0d\x05\0\0\x0c\0\0\0\0\x02\0\0\x15\x05\0\0\x7e\0\0\0\x20\x02\0\0\
\x1c\x05\0\0\x7f\0\0\0\x40\x02\0\0\x27\x05\0\0\x82\0\0\0\x40\x03\0\0\x2d\x05\0\
\0\x84\0\0\0\x80\x03\0\0\x35\x05\0\0\x92\0\0\0\x80\x04\0\0\x3c\x05\0\0\x94\0\0\
\0\xc0\x04\0\0\x41\x05\0\0\x2a\0\0\0\xc0\x05\0\0\x4b\x05\0\0\x47\0\0\0\0\x06\0\
\0\x56\x05\0\0\x47\0\0\0\x40\x06\0\0\x63\x05\0\0\x95\0\0\0\x80\x06\0\0\x68\x05\
\0\0\x96\0\0\0\xc0\x06\0\0\x72\x05\0\0\x97\0\0\0\0\x07\0\0\x7b\x05\0\0\x97\0\0\
\0\x20\x07\0\0\0\0\0\0\x02\0\0\x05\x10\0\0\0\x84\x05\0\0\x71\0\0\0\0\0\0\0\x8d\
\x05\0\0\x51\0\0\0\0\0\0\0\x98\x05\0\0\x01\0\0\x04\x08\0\0\0\x7a\x01\0\0\x72\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x71\0\0\0\xa3\x05\0\0\x02\0\0\x04\x10\0\0\0\xa8\
\x05\0\0\x74\0\0\0\0\0\0\0\xb3\0\0\0\x25\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\x02\xa9\
\0\0\0\0\0\0\0\0\0\0\x02\x76\0\0\0\0\0\0\0\0\0\0\x0a\xa1\0\0\0\xac\x05\0\0\x06\
\0\0\x06\x04\0\0\0\xb4\x05\0\0\0\0\0\0\xc7\x05\0\0\x01\0\0\0\xd7\x05\0\0\x02\0\
\0\0\xe8\x05\0\0\x03\0\0\0\xfa\x05\0\0\x04\0\0\0\x0a\x06\0\0\x05\0\0\0\x1d\x06\
\0\0\0\0\0\x08\x79\0\0\0\x2b\x06\0\0\0\0\0\x08\x7a\0\0\0\0\0\0\0\x01\0\0\x04\
\x08\0\0\0\x32\x02\0\0\x7b\0\0\0\0\0\0\0\x36\x06\0\0\0\0\0\x08\x7c\0\0\0\x3a\
\x06\0\0\0\0\0\x08\x7d\0\0\0\x40\x06\0\0\0\0\0\x01\x08\0\0\0\x40\0\0\x01\x4a\
\x06\0\0\0\0\0\x08\x0c\0\0\0\x52\x06\0\0\x04\0\0\x04\x20\0\0\0\x58\x06\0\0\x78\
\0\0\0\0\0\0\0\x5e\x06\0\0\x80\0\0\0\x40\0\0\0\x68\x06\0\0\x81\0\0\0\x60\0\0\0\
\x6c\x06\0\0\x49\0\0\0\x80\0\0\0\x76\x06\0\0\0\0\0\x08\x36\0\0\0\x85\x06\0\0\
\x01\0\0\x04\x04\0\0\0\x60\x02\0\0\x3a\0\0\0\0\0\0\0\x9b\x06\0\0\0\0\0\x08\x83\
\0\0\0\xa2\x06\0\0\0\0\0\x08\x7d\0\0\0\xb2\x06\0\0\x06\0\0\x04\x20\0\0\0\xd0\
\x01\0\0\x85\0\0\0\0\0\0\0\xbe\x06\0\0\x8c\0\0\0\x40\0\0\0\xc2\x06\0\0\x8d\0\0\
\0\x80\0\0\0\xcb\x06\0\0\x8e\0\0\0\xa0\0\0\0\xcf\x06\0\0\x8e\0\0\0\xc0\0\0\0\
\xd4\x06\0\0\x02\0\0\0\xe0\0\0\0\xdb\x06\0\0\0\0\0\x08\x86\0\0\0\0\0\0\0\x01\0\
\0\x04\x08\0\0\0\x02\x02\0\0\x87\0\0\0\0\0\0\0\xe4\x06\0\0\0\0\0\x08\x88\0\0\0\
\xf2\x06\0\0\x02\0\0\x04\x08\0\0\0\0\0\0\0\x89\0\0\0\0\0\0\0\x5e\x06\0\0\x37\0\
\0\0\x20\0\0\0\0\0\0\0\x02\0\0\x05\x04\0\0\0\xfa\x06\0\0\x3a\0\0\0\0\0\0\0\0\0\
\0\0\x8a\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\x04\x04\0\0\0\xff\x06\0\0\x3d\0\0\0\0\0\
\0\0\x07\x07\0\0\x8b\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x3d\0\0\0\x04\0\
\0\0\x03\0\0\0\0\0\0\0\0\0\0\x02\xa5\0\0\0\xc2\x06\0\0\x05\0\0\x06\x04\0\0\0\
\x10\x07\0\0\0\0\0\0\x1c\x07\0\0\x01\0\0\0\x29\x07\0\0\x02\0\0\0\x36\x07\0\0\
\x03\0\0\0\x42\x07\0\0\x04\0\0\0\x4e\x07\0\0\0\0\0\x08\x8f\0\0\0\0\0\0\0\x01\0\
\0\x04\x04\0\0\0\x25\x02\0\0\x90\0\0\0\0\0\0\0\x55\x07\0\0\0\0\0\x08\x91\0\0\0\
\x5b\x07\0\0\0\0\0\x08\x0c\0\0\0\0\0\0\0\0\0\0\x02\x93\0\0\0\0\0\0\0\0\0\0\x0a\
\x9e\0\0\0\x6c\x07\0\0\x06\0\0\x04\x20\0\0\0\x7a\x07\0\0\x46\0\0\0\0\0\0\0\x80\
\x07\0\0\x0c\0\0\0\x40\0\0\0\x85\x07\0\0\x0c\0\0\0\x60\0\0\0\x90\x07\0\0\x0c\0\
\0\0\x80\0\0\0\x99\x07\0\0\x0c\0\0\0\xa0\0\0\0\xa3\x07\0\0\x82\0\0\0\xc0\0\0\0\
\0\0\0\0\0\0\0\x02\xa2\0\0\0\0\0\0\0\0\0\0\x02\x9d\0\0\0\xac\x07\0\0\0\0\0\x08\
\x29\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x6b\0\0\0\x04\0\0\0\x04\0\0\0\xb5\x07\0\0\
\0\0\0\x0e\x98\0\0\0\x01\0\0\0\xbe\x07\0\0\0\0\0\x0e\x02\0\0\0\x01\0\0\0\xcc\
\x07\0\0\0\0\0\x0e\x02\0\0\0\x01\0\0\0\xe1\x07\0\0\0\0\0\x0e\x02\0\0\0\x01\0\0\
\0\xf3\x07\0\0\0\0\0\x07\0\0\0\0\x49\x04\0\0\0\0\0\x07\0\0\0\0\x01\x08\0\0\0\0\
\0\x07\0\0\0\0\x13\x08\0\0\0\0\0\x07\0\0\0\0\x21\x08\0\0\0\0\0\x07\0\0\0\0\x31\
\x08\0\0\0\0\0\x07\0\0\0\0\x3c\x08\0\0\0\0\0\x07\0\0\0\0\x42\x08\0\0\0\0\0\x07\
\0\0\0\0\xbe\x06\0\0\0\0\0\x07\0\0\0\0\x4c\x08\0\0\0\0\0\x07\0\0\0\0\x56\x08\0\
\0\0\0\0\x07\0\0\0\0\x5b\x08\0\0\0\0\0\x07\0\0\0\0\x67\x08\0\0\0\0\0\x07\0\0\0\
\0\x70\x08\0\0\0\0\0\x07\0\0\0\0\x43\x0e\0\0\x01\0\0\x0f\x04\0\0\0\x99\0\0\0\0\
\0\0\0\x04\0\0\0\x4b\x0e\0\0\x01\0\0\x0f\x04\0\0\0\x9a\0\0\0\0\0\0\0\x04\0\0\0\
\x50\x0e\0\0\x02\0\0\x0f\x08\0\0\0\x9b\0\0\0\0\0\0\0\x04\0\0\0\x9c\0\0\0\x04\0\
\0\0\x04\0\0\0\x56\x0e\0\0\x03\0\0\x0f\x60\0\0\0\x0e\0\0\0\0\0\0\0\x20\0\0\0\
\x14\0\0\0\x20\0\0\0\x20\0\0\0\x18\0\0\0\x40\0\0\0\x20\0\0\0\0\x69\x6e\x74\0\
\x5f\x5f\x41\x52\x52\x41\x59\x5f\x53\x49\x5a\x45\x5f\x54\x59\x50\x45\x5f\x5f\0\
\x6c\x6f\x63\x61\x6c\x5f\x73\x74\x6f\x72\x61\x67\x65\0\x65\x78\x65\x63\x5f\x69\
\x6e\x6f\x64\x65\0\x76\x61\x6c\x75\x65\0\x5f\x5f\x75\x33\x32\0\x75\x6e\x73\x69\
\x67\x6e\x65\x64\x20\x69\x6e\x74\0\x74\x79\x70\x65\0\x6d\x61\x70\x5f\x66\x6c\
\x61\x67\x73\0\x6b\x65\x79\0\x69\x6e\x6f\x64\x65\x5f\x73\x74\x6f\x72\x61\x67\
\x65\x5f\x6d\x61\x70\0\x73\x6b\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x6d\x61\x70\
\0\x74\x61\x73\x6b\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x6d\x61\x70\0\x75\x6e\
\x73\x69\x67\x6e\x65\x64\x20\x6c\x6f\x6e\x67\x20\x6c\x6f\x6e\x67\0\x63\x74\x78\
\0\x75\x6e\x6c\x69\x6e\x6b\x5f\x68\x6f\x6f\x6b\0\x64\x65\x6e\x74\x72\x79\0\x64\
\x5f\x66\x6c\x61\x67\x73\0\x64\x5f\x73\x65\x71\0\x64\x5f\x68\x61\x73\x68\0\x64\
\x5f\x70\x61\x72\x65\x6e\x74\0\x64\x5f\x6e\x61\x6d\x65\0\x64\x5f\x69\x6e\x6f\
\x64\x65\0\x64\x5f\x69\x6e\x61\x6d\x65\0\x64\x5f\x6c\x6f\x63\x6b\x72\x65\x66\0\
\x64\x5f\x6f\x70\0\x64\x5f\x73\x62\0\x64\x5f\x74\x69\x6d\x65\0\x64\x5f\x66\x73\
\x64\x61\x74\x61\0\x64\x5f\x63\x68\x69\x6c\x64\0\x64\x5f\x73\x75\x62\x64\x69\
\x72\x73\0\x64\x5f\x75\0\x73\x65\x71\x63\x6f\x75\x6e\x74\x5f\x73\x70\x69\x6e\
\x6c\x6f\x63\x6b\x5f\x74\0\x73\x65\x71\x63\x6f\x75\x6e\x74\x5f\x73\x70\x69\x6e\
\x6c\x6f\x63\x6b\0\x73\x65\x71\x63\x6f\x75\x6e\x74\0\x73\x65\x71\x63\x6f\x75\
\x6e\x74\x5f\x74\0\x73\x65\x71\x75\x65\x6e\x63\x65\0\x68\x6c\x69\x73\x74\x5f\
\x62\x6c\x5f\x6e\x6f\x64\x65\0\x6e\x65\x78\x74\0\x70\x70\x72\x65\x76\0\x71\x73\
\x74\x72\0\x6e\x61\x6d\x65\0\x68\x61\x73\x68\x5f\x6c\x65\x6e\0\x68\x61\x73\x68\
\0\x6c\x65\x6e\0\x75\x33\x32\0\x75\x36\x34\0\x5f\x5f\x75\x36\x34\0\x75\x6e\x73\
\x69\x67\x6e\x65\x64\x20\x63\x68\x61\x72\0\x6c\x6f\x63\x6b\x72\x65\x66\0\x6c\
\x6f\x63\x6b\x5f\x63\x6f\x75\x6e\x74\0\x6c\x6f\x63\x6b\0\x63\x6f\x75\x6e\x74\0\
\x73\x70\x69\x6e\x6c\x6f\x63\x6b\x5f\x74\0\x73\x70\x69\x6e\x6c\x6f\x63\x6b\0\
\x72\x6c\x6f\x63\x6b\0\x72\x61\x77\x5f\x73\x70\x69\x6e\x6c\x6f\x63\x6b\0\x72\
\x61\x77\x5f\x6c\x6f\x63\x6b\0\x61\x72\x63\x68\x5f\x73\x70\x69\x6e\x6c\x6f\x63\
\x6b\x5f\x74\0\x71\x73\x70\x69\x6e\x6c\x6f\x63\x6b\0\x76\x61\x6c\0\x61\x74\x6f\
\x6d\x69\x63\x5f\x74\0\x63\x6f\x75\x6e\x74\x65\x72\0\x6c\x6f\x63\x6b\x65\x64\0\
\x70\x65\x6e\x64\x69\x6e\x67\0\x75\x38\0\x5f\x5f\x75\x38\0\x6c\x6f\x63\x6b\x65\
\x64\x5f\x70\x65\x6e\x64\x69\x6e\x67\0\x74\x61\x69\x6c\0\x75\x31\x36\0\x5f\x5f\
\x75\x31\x36\0\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x73\x68\x6f\x72\x74\0\x75\
\x6e\x73\x69\x67\x6e\x65\x64\x20\x6c\x6f\x6e\x67\0\x64\x5f\x6c\x72\x75\0\x64\
\x5f\x77\x61\x69\x74\0\x6c\x69\x73\x74\x5f\x68\x65\x61\x64\0\x70\x72\x65\x76\0\
\x77\x61\x69\x74\x5f\x71\x75\x65\x75\x65\x5f\x68\x65\x61\x64\x5f\x74\0\x64\x5f\
\x61\x6c\x69\x61\x73\0\x64\x5f\x69\x6e\x5f\x6c\x6f\x6f\x6b\x75\x70\x5f\x68\x61\
\x73\x68\0\x64\x5f\x72\x63\x75\0\x68\x6c\x69\x73\x74\x5f\x6e\x6f\x64\x65\0\x63\
\x61\x6c\x6c\x62\x61\x63\x6b\x5f\x68\x65\x61\x64\0\x66\x75\x6e\x63\0\x69\x6e\
\x6f\x64\x65\x5f\x72\x65\x6e\x61\x6d\x65\0\x73\x6f\x63\x6b\x65\x74\x5f\x62\x69\
\x6e\x64\0\x73\x6f\x63\x6b\x65\x74\0\x73\x74\x61\x74\x65\0\x66\x6c\x61\x67\x73\
\0\x66\x69\x6c\x65\0\x73\x6b\0\x6f\x70\x73\0\x77\x71\0\x73\x6f\x63\x6b\x65\x74\
\x5f\x73\x74\x61\x74\x65\0\x53\x53\x5f\x46\x52\x45\x45\0\x53\x53\x5f\x55\x4e\
\x43\x4f\x4e\x4e\x45\x43\x54\x45\x44\0\x53\x53\x5f\x43\x4f\x4e\x4e\x45\x43\x54\
\x49\x4e\x47\0\x53\x53\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x45\x44\0\x53\x53\x5f\
\x44\x49\x53\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4e\x47\0\x73\x68\x6f\x72\x74\0\
\x73\x6f\x63\x6b\x65\x74\x5f\x77\x71\0\x77\x61\x69\x74\0\x66\x61\x73\x79\x6e\
\x63\x5f\x6c\x69\x73\x74\0\x72\x63\x75\0\x77\x61\x69\x74\x5f\x71\x75\x65\x75\
\x65\x5f\x68\x65\x61\x64\0\x68\x65\x61\x64\0\x73\x6f\x63\x6b\x65\x74\x5f\x70\
\x6f\x73\x74\x5f\x63\x72\x65\x61\x74\x65\0\x65\x78\x65\x63\0\x6c\x69\x6e\x75\
\x78\x5f\x62\x69\x6e\x70\x72\x6d\0\x76\x6d\x61\0\x76\x6d\x61\x5f\x70\x61\x67\
\x65\x73\0\x6d\x6d\0\x70\0\x61\x72\x67\x6d\x69\x6e\0\x68\x61\x76\x65\x5f\x65\
\x78\x65\x63\x66\x64\0\x65\x78\x65\x63\x66\x64\x5f\x63\x72\x65\x64\x73\0\x73\
\x65\x63\x75\x72\x65\x65\x78\x65\x63\0\x70\x6f\x69\x6e\x74\x5f\x6f\x66\x5f\x6e\
\x6f\x5f\x72\x65\x74\x75\x72\x6e\0\x65\x78\x65\x63\x75\x74\x61\x62\x6c\x65\0\
\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65\x72\0\x63\x72\x65\x64\0\x75\x6e\x73\
\x61\x66\x65\0\x70\x65\x72\x5f\x63\x6c\x65\x61\x72\0\x61\x72\x67\x63\0\x65\x6e\
\x76\x63\0\x66\x69\x6c\x65\x6e\x61\x6d\x65\0\x69\x6e\x74\x65\x72\x70\0\x66\x64\
\x70\x61\x74\x68\0\x69\x6e\x74\x65\x72\x70\x5f\x66\x6c\x61\x67\x73\0\x65\x78\
\x65\x63\x66\x64\0\x6c\x6f\x61\x64\x65\x72\0\x72\x6c\x69\x6d\x5f\x73\x74\x61\
\x63\x6b\0\x62\x75\x66\0\x63\x68\x61\x72\0\x72\x6c\x69\x6d\x69\x74\0\x72\x6c\
\x69\x6d\x5f\x63\x75\x72\0\x72\x6c\x69\x6d\x5f\x6d\x61\x78\0\x5f\x5f\x6b\x65\
\x72\x6e\x65\x6c\x5f\x75\x6c\x6f\x6e\x67\x5f\x74\0\x66\x5f\x75\0\x66\x5f\x70\
\x61\x74\x68\0\x66\x5f\x69\x6e\x6f\x64\x65\0\x66\x5f\x6f\x70\0\x66\x5f\x6c\x6f\
\x63\x6b\0\x66\x5f\x77\x72\x69\x74\x65\x5f\x68\x69\x6e\x74\0\x66\x5f\x63\x6f\
\x75\x6e\x74\0\x66\x5f\x66\x6c\x61\x67\x73\0\x66\x5f\x6d\x6f\x64\x65\0\x66\x5f\
\x70\x6f\x73\x5f\x6c\x6f\x63\x6b\0\x66\x5f\x70\x6f\x73\0\x66\x5f\x6f\x77\x6e\
\x65\x72\0\x66\x5f\x63\x72\x65\x64\0\x66\x5f\x72\x61\0\x66\x5f\x76\x65\x72\x73\
\x69\x6f\x6e\0\x66\x5f\x73\x65\x63\x75\x72\x69\x74\x79\0\x70\x72\x69\x76\x61\
\x74\x65\x5f\x64\x61\x74\x61\0\x66\x5f\x65\x70\0\x66\x5f\x6d\x61\x70\x70\x69\
\x6e\x67\0\x66\x5f\x77\x62\x5f\x65\x72\x72\0\x66\x5f\x73\x62\x5f\x65\x72\x72\0\
\x66\x75\x5f\x6c\x6c\x69\x73\x74\0\x66\x75\x5f\x72\x63\x75\x68\x65\x61\x64\0\
\x6c\x6c\x69\x73\x74\x5f\x6e\x6f\x64\x65\0\x70\x61\x74\x68\0\x6d\x6e\x74\0\x72\
\x77\x5f\x68\x69\x6e\x74\0\x57\x52\x49\x54\x45\x5f\x4c\x49\x46\x45\x5f\x4e\x4f\
\x54\x5f\x53\x45\x54\0\x57\x52\x49\x54\x45\x5f\x4c\x49\x46\x45\x5f\x4e\x4f\x4e\
\x45\0\x57\x52\x49\x54\x45\x5f\x4c\x49\x46\x45\x5f\x53\x48\x4f\x52\x54\0\x57\
\x52\x49\x54\x45\x5f\x4c\x49\x46\x45\x5f\x4d\x45\x44\x49\x55\x4d\0\x57\x52\x49\
\x54\x45\x5f\x4c\x49\x46\x45\x5f\x4c\x4f\x4e\x47\0\x57\x52\x49\x54\x45\x5f\x4c\
\x49\x46\x45\x5f\x45\x58\x54\x52\x45\x4d\x45\0\x61\x74\x6f\x6d\x69\x63\x5f\x6c\
\x6f\x6e\x67\x5f\x74\0\x61\x74\x6f\x6d\x69\x63\x36\x34\x5f\x74\0\x73\x36\x34\0\
\x5f\x5f\x73\x36\x34\0\x6c\x6f\x6e\x67\x20\x6c\x6f\x6e\x67\0\x66\x6d\x6f\x64\
\x65\x5f\x74\0\x6d\x75\x74\x65\x78\0\x6f\x77\x6e\x65\x72\0\x77\x61\x69\x74\x5f\
\x6c\x6f\x63\x6b\0\x6f\x73\x71\0\x77\x61\x69\x74\x5f\x6c\x69\x73\x74\0\x72\x61\
\x77\x5f\x73\x70\x69\x6e\x6c\x6f\x63\x6b\x5f\x74\0\x6f\x70\x74\x69\x6d\x69\x73\
\x74\x69\x63\x5f\x73\x70\x69\x6e\x5f\x71\x75\x65\x75\x65\0\x6c\x6f\x66\x66\x5f\
\x74\0\x5f\x5f\x6b\x65\x72\x6e\x65\x6c\x5f\x6c\x6f\x66\x66\x5f\x74\0\x66\x6f\
\x77\x6e\x5f\x73\x74\x72\x75\x63\x74\0\x70\x69\x64\0\x70\x69\x64\x5f\x74\x79\
\x70\x65\0\x75\x69\x64\0\x65\x75\x69\x64\0\x73\x69\x67\x6e\x75\x6d\0\x72\x77\
\x6c\x6f\x63\x6b\x5f\x74\0\x61\x72\x63\x68\x5f\x72\x77\x6c\x6f\x63\x6b\x5f\x74\
\0\x71\x72\x77\x6c\x6f\x63\x6b\0\x63\x6e\x74\x73\0\x77\x6c\x6f\x63\x6b\x65\x64\
\0\x5f\x5f\x6c\x73\x74\x61\x74\x65\0\x50\x49\x44\x54\x59\x50\x45\x5f\x50\x49\
\x44\0\x50\x49\x44\x54\x59\x50\x45\x5f\x54\x47\x49\x44\0\x50\x49\x44\x54\x59\
\x50\x45\x5f\x50\x47\x49\x44\0\x50\x49\x44\x54\x59\x50\x45\x5f\x53\x49\x44\0\
\x50\x49\x44\x54\x59\x50\x45\x5f\x4d\x41\x58\0\x6b\x75\x69\x64\x5f\x74\0\x75\
\x69\x64\x5f\x74\0\x5f\x5f\x6b\x65\x72\x6e\x65\x6c\x5f\x75\x69\x64\x33\x32\x5f\
\x74\0\x66\x69\x6c\x65\x5f\x72\x61\x5f\x73\x74\x61\x74\x65\0\x73\x74\x61\x72\
\x74\0\x73\x69\x7a\x65\0\x61\x73\x79\x6e\x63\x5f\x73\x69\x7a\x65\0\x72\x61\x5f\
\x70\x61\x67\x65\x73\0\x6d\x6d\x61\x70\x5f\x6d\x69\x73\x73\0\x70\x72\x65\x76\
\x5f\x70\x6f\x73\0\x65\x72\x72\x73\x65\x71\x5f\x74\0\x5f\x6c\x69\x63\x65\x6e\
\x73\x65\0\x6d\x6f\x6e\x69\x74\x6f\x72\x65\x64\x5f\x70\x69\x64\0\x69\x6e\x6f\
\x64\x65\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x72\x65\x73\x75\x6c\x74\0\x73\x6b\
\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x72\x65\x73\x75\x6c\x74\0\x61\x64\x64\x72\
\x65\x73\x73\x5f\x73\x70\x61\x63\x65\0\x64\x65\x6e\x74\x72\x79\x5f\x6f\x70\x65\
\x72\x61\x74\x69\x6f\x6e\x73\0\x66\x61\x73\x79\x6e\x63\x5f\x73\x74\x72\x75\x63\
\x74\0\x66\x69\x6c\x65\x5f\x6f\x70\x65\x72\x61\x74\x69\x6f\x6e\x73\0\x68\x6c\
\x69\x73\x74\x5f\x68\x65\x61\x64\0\x69\x6e\x6f\x64\x65\0\x6d\x6d\x5f\x73\x74\
\x72\x75\x63\x74\0\x70\x72\x6f\x74\x6f\x5f\x6f\x70\x73\0\x73\x6f\x63\x6b\0\x73\
\x75\x70\x65\x72\x5f\x62\x6c\x6f\x63\x6b\0\x76\x66\x73\x6d\x6f\x75\x6e\x74\0\
\x76\x6d\x5f\x61\x72\x65\x61\x5f\x73\x74\x72\x75\x63\x74\0\x2f\x62\x75\x69\x6c\
\x64\x64\x69\x72\x2f\x62\x75\x69\x6c\x64\x2f\x42\x55\x49\x4c\x44\x2f\x6b\x65\
\x72\x6e\x65\x6c\x2d\x35\x2e\x31\x34\x2e\x30\x2d\x31\x37\x31\x2e\x65\x6c\x39\
\x2f\x6c\x69\x6e\x75\x78\x2d\x35\x2e\x31\x34\x2e\x30\x2d\x31\x37\x31\x2e\x65\
\x6c\x39\x2e\x78\x38\x36\x5f\x36\x34\x2f\x74\x6f\x6f\x6c\x73\x2f\x74\x65\x73\
\x74\x69\x6e\x67\x2f\x73\x65\x6c\x66\x74\x65\x73\x74\x73\x2f\x62\x70\x66\x2f\
\x70\x72\x6f\x67\x73\x2f\x6c\x6f\x63\x61\x6c\x5f\x73\x74\x6f\x72\x61\x67\x65\
\x2e\x63\0\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x75\x6e\x6c\x69\
\x6e\x6b\x5f\x68\x6f\x6f\x6b\x2c\x20\x73\x74\x72\x75\x63\x74\x20\x69\x6e\x6f\
\x64\x65\x20\x2a\x64\x69\x72\x2c\x20\x73\x74\x72\x75\x63\x74\x20\x64\x65\x6e\
\x74\x72\x79\x20\x2a\x76\x69\x63\x74\x69\x6d\x29\0\x09\x5f\x5f\x75\x33\x32\x20\
\x70\x69\x64\x20\x3d\x20\x62\x70\x66\x5f\x67\x65\x74\x5f\x63\x75\x72\x72\x65\
\x6e\x74\x5f\x70\x69\x64\x5f\x74\x67\x69\x64\x28\x29\x20\x3e\x3e\x20\x33\x32\
\x3b\0\x09\x69\x66\x20\x28\x70\x69\x64\x20\x21\x3d\x20\x6d\x6f\x6e\x69\x74\x6f\
\x72\x65\x64\x5f\x70\x69\x64\x29\0\x09\x09\x09\x09\x20\x20\x20\x20\x20\x20\x20\
\x62\x70\x66\x5f\x67\x65\x74\x5f\x63\x75\x72\x72\x65\x6e\x74\x5f\x74\x61\x73\
\x6b\x5f\x62\x74\x66\x28\x29\x2c\x20\x30\x2c\x20\x30\x29\x3b\0\x09\x73\x74\x6f\
\x72\x61\x67\x65\x20\x3d\x20\x62\x70\x66\x5f\x74\x61\x73\x6b\x5f\x73\x74\x6f\
\x72\x61\x67\x65\x5f\x67\x65\x74\x28\x26\x74\x61\x73\x6b\x5f\x73\x74\x6f\x72\
\x61\x67\x65\x5f\x6d\x61\x70\x2c\0\x09\x69\x66\x20\x28\x73\x74\x6f\x72\x61\x67\
\x65\x29\x20\x7b\0\x09\x09\x69\x73\x5f\x73\x65\x6c\x66\x5f\x75\x6e\x6c\x69\x6e\
\x6b\x20\x3d\x20\x73\x74\x6f\x72\x61\x67\x65\x2d\x3e\x65\x78\x65\x63\x5f\x69\
\x6e\x6f\x64\x65\x20\x3d\x3d\x20\x76\x69\x63\x74\x69\x6d\x2d\x3e\x64\x5f\x69\
\x6e\x6f\x64\x65\x3b\0\x09\x09\x69\x66\x20\x28\x69\x73\x5f\x73\x65\x6c\x66\x5f\
\x75\x6e\x6c\x69\x6e\x6b\x29\0\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\
\x28\x69\x6e\x6f\x64\x65\x5f\x72\x65\x6e\x61\x6d\x65\x2c\x20\x73\x74\x72\x75\
\x63\x74\x20\x69\x6e\x6f\x64\x65\x20\x2a\x6f\x6c\x64\x5f\x64\x69\x72\x2c\x20\
\x73\x74\x72\x75\x63\x74\x20\x64\x65\x6e\x74\x72\x79\x20\x2a\x6f\x6c\x64\x5f\
\x64\x65\x6e\x74\x72\x79\x2c\0\x09\x62\x70\x66\x5f\x69\x6e\x6f\x64\x65\x5f\x73\
\x74\x6f\x72\x61\x67\x65\x5f\x67\x65\x74\x28\x26\x69\x6e\x6f\x64\x65\x5f\x73\
\x74\x6f\x72\x61\x67\x65\x5f\x6d\x61\x70\x2c\x20\x6e\x65\x77\x5f\x64\x65\x6e\
\x74\x72\x79\x2d\x3e\x64\x5f\x69\x6e\x6f\x64\x65\x2c\x20\x30\x2c\0\x09\x73\x74\
\x6f\x72\x61\x67\x65\x20\x3d\x20\x62\x70\x66\x5f\x69\x6e\x6f\x64\x65\x5f\x73\
\x74\x6f\x72\x61\x67\x65\x5f\x67\x65\x74\x28\x26\x69\x6e\x6f\x64\x65\x5f\x73\
\x74\x6f\x72\x61\x67\x65\x5f\x6d\x61\x70\x2c\x20\x6f\x6c\x64\x5f\x64\x65\x6e\
\x74\x72\x79\x2d\x3e\x64\x5f\x69\x6e\x6f\x64\x65\x2c\0\x09\x69\x66\x20\x28\x21\
\x73\x74\x6f\x72\x61\x67\x65\x29\0\x09\x69\x66\x20\x28\x73\x74\x6f\x72\x61\x67\
\x65\x2d\x3e\x76\x61\x6c\x75\x65\x20\x21\x3d\x20\x44\x55\x4d\x4d\x59\x5f\x53\
\x54\x4f\x52\x41\x47\x45\x5f\x56\x41\x4c\x55\x45\x29\0\x09\x09\x69\x6e\x6f\x64\
\x65\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x72\x65\x73\x75\x6c\x74\x20\x3d\x20\
\x2d\x31\x3b\0\x09\x65\x72\x72\x20\x3d\x20\x62\x70\x66\x5f\x69\x6e\x6f\x64\x65\
\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x64\x65\x6c\x65\x74\x65\x28\x26\x69\x6e\
\x6f\x64\x65\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x6d\x61\x70\x2c\x20\x6f\x6c\
\x64\x5f\x64\x65\x6e\x74\x72\x79\x2d\x3e\x64\x5f\x69\x6e\x6f\x64\x65\x29\x3b\0\
\x09\x69\x66\x20\x28\x21\x65\x72\x72\x29\0\x09\x09\x69\x6e\x6f\x64\x65\x5f\x73\
\x74\x6f\x72\x61\x67\x65\x5f\x72\x65\x73\x75\x6c\x74\x20\x3d\x20\x65\x72\x72\
\x3b\0\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x73\x6f\x63\x6b\x65\
\x74\x5f\x62\x69\x6e\x64\x2c\x20\x73\x74\x72\x75\x63\x74\x20\x73\x6f\x63\x6b\
\x65\x74\x20\x2a\x73\x6f\x63\x6b\x2c\x20\x73\x74\x72\x75\x63\x74\x20\x73\x6f\
\x63\x6b\x61\x64\x64\x72\x20\x2a\x61\x64\x64\x72\x65\x73\x73\x2c\0\x09\x73\x74\
\x6f\x72\x61\x67\x65\x20\x3d\x20\x62\x70\x66\x5f\x73\x6b\x5f\x73\x74\x6f\x72\
\x61\x67\x65\x5f\x67\x65\x74\x28\x26\x73\x6b\x5f\x73\x74\x6f\x72\x61\x67\x65\
\x5f\x6d\x61\x70\x2c\x20\x73\x6f\x63\x6b\x2d\x3e\x73\x6b\x2c\x20\x30\x2c\0\x09\
\x09\x73\x6b\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x72\x65\x73\x75\x6c\x74\x20\
\x3d\x20\x2d\x31\x3b\0\x09\x65\x72\x72\x20\x3d\x20\x62\x70\x66\x5f\x73\x6b\x5f\
\x73\x74\x6f\x72\x61\x67\x65\x5f\x64\x65\x6c\x65\x74\x65\x28\x26\x73\x6b\x5f\
\x73\x74\x6f\x72\x61\x67\x65\x5f\x6d\x61\x70\x2c\x20\x73\x6f\x63\x6b\x2d\x3e\
\x73\x6b\x29\x3b\0\x09\x09\x73\x6b\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x72\x65\
\x73\x75\x6c\x74\x20\x3d\x20\x65\x72\x72\x3b\0\x69\x6e\x74\x20\x42\x50\x46\x5f\
\x50\x52\x4f\x47\x28\x73\x6f\x63\x6b\x65\x74\x5f\x70\x6f\x73\x74\x5f\x63\x72\
\x65\x61\x74\x65\x2c\x20\x73\x74\x72\x75\x63\x74\x20\x73\x6f\x63\x6b\x65\x74\
\x20\x2a\x73\x6f\x63\x6b\x2c\x20\x69\x6e\x74\x20\x66\x61\x6d\x69\x6c\x79\x2c\
\x20\x69\x6e\x74\x20\x74\x79\x70\x65\x2c\0\x09\x73\x74\x6f\x72\x61\x67\x65\x2d\
\x3e\x76\x61\x6c\x75\x65\x20\x3d\x20\x44\x55\x4d\x4d\x59\x5f\x53\x54\x4f\x52\
\x41\x47\x45\x5f\x56\x41\x4c\x55\x45\x3b\0\x76\x6f\x69\x64\x20\x42\x50\x46\x5f\
\x50\x52\x4f\x47\x28\x65\x78\x65\x63\x2c\x20\x73\x74\x72\x75\x63\x74\x20\x6c\
\x69\x6e\x75\x78\x5f\x62\x69\x6e\x70\x72\x6d\x20\x2a\x62\x70\x72\x6d\x29\0\x09\
\x09\x09\x09\x20\x20\x20\x20\x20\x20\x20\x62\x70\x66\x5f\x67\x65\x74\x5f\x63\
\x75\x72\x72\x65\x6e\x74\x5f\x74\x61\x73\x6b\x5f\x62\x74\x66\x28\x29\x2c\x20\
\x30\x2c\0\x09\x69\x66\x20\x28\x73\x74\x6f\x72\x61\x67\x65\x29\0\x09\x09\x73\
\x74\x6f\x72\x61\x67\x65\x2d\x3e\x65\x78\x65\x63\x5f\x69\x6e\x6f\x64\x65\x20\
\x3d\x20\x62\x70\x72\x6d\x2d\x3e\x66\x69\x6c\x65\x2d\x3e\x66\x5f\x69\x6e\x6f\
\x64\x65\x3b\0\x09\x73\x74\x6f\x72\x61\x67\x65\x20\x3d\x20\x62\x70\x66\x5f\x69\
\x6e\x6f\x64\x65\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x67\x65\x74\x28\x26\x69\
\x6e\x6f\x64\x65\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x6d\x61\x70\x2c\x20\x62\
\x70\x72\x6d\x2d\x3e\x66\x69\x6c\x65\x2d\x3e\x66\x5f\x69\x6e\x6f\x64\x65\x2c\0\
\x30\x3a\x35\0\x30\x3a\x34\0\x30\x3a\x31\x31\0\x30\x3a\x32\0\x6c\x69\x63\x65\
\x6e\x73\x65\0\x2e\x62\x73\x73\0\x2e\x64\x61\x74\x61\0\x2e\x6d\x61\x70\x73\0\
\x6c\x73\x6d\x2f\x69\x6e\x6f\x64\x65\x5f\x75\x6e\x6c\x69\x6e\x6b\0\x6c\x73\x6d\
\x2e\x73\x2f\x69\x6e\x6f\x64\x65\x5f\x72\x65\x6e\x61\x6d\x65\0\x6c\x73\x6d\x2e\
\x73\x2f\x73\x6f\x63\x6b\x65\x74\x5f\x62\x69\x6e\x64\0\x6c\x73\x6d\x2e\x73\x2f\
\x73\x6f\x63\x6b\x65\x74\x5f\x70\x6f\x73\x74\x5f\x63\x72\x65\x61\x74\x65\0\x6c\
\x73\x6d\x2e\x73\x2f\x62\x70\x72\x6d\x5f\x63\x6f\x6d\x6d\x69\x74\x74\x65\x64\
\x5f\x63\x72\x65\x64\x73\0\0\0\x9f\xeb\x01\0\x20\0\0\0\0\0\0\0\x54\0\0\0\x54\0\
\0\0\x9c\x04\0\0\xf0\x04\0\0\xdc\0\0\0\x08\0\0\0\x5c\x0e\0\0\x01\0\0\0\0\0\0\0\
\x1c\0\0\0\x6d\x0e\0\0\x01\0\0\0\0\0\0\0\x55\0\0\0\x80\x0e\0\0\x01\0\0\0\0\0\0\
\0\x56\0\0\0\x92\x0e\0\0\x01\0\0\0\0\0\0\0\x62\0\0\0\xab\x0e\0\0\x01\0\0\0\0\0\
\0\0\x64\0\0\0\x10\0\0\0\x5c\x0e\0\0\x0d\0\0\0\0\0\0\0\x7f\x08\0\0\xf9\x08\0\0\
\0\xbc\0\0\x08\0\0\0\x7f\x08\0\0\xf9\x08\0\0\x05\xbc\0\0\x10\0\0\0\x7f\x08\0\0\
\x3d\x09\0\0\x0e\xc4\0\0\x18\0\0\0\x7f\x08\0\0\x6c\x09\0\0\x0d\xd4\0\0\x30\0\0\
\0\x7f\x08\0\0\x3d\x09\0\0\x29\xc4\0\0\x38\0\0\0\x7f\x08\0\0\x6c\x09\0\0\x06\
\xd4\0\0\x40\0\0\0\x7f\x08\0\0\x87\x09\0\0\x0c\xe4\0\0\x48\0\0\0\x7f\x08\0\0\
\xb5\x09\0\0\x0c\xe0\0\0\x78\0\0\0\x7f\x08\0\0\xe8\x09\0\0\x06\xe8\0\0\x88\0\0\
\0\x7f\x08\0\0\xf8\x09\0\0\x33\xf0\0\0\x90\0\0\0\x7f\x08\0\0\xf8\x09\0\0\x1d\
\xf0\0\0\x98\0\0\0\x7f\x08\0\0\x33\x0a\0\0\x07\xf4\0\0\xa8\0\0\0\x7f\x08\0\0\
\xf9\x08\0\0\x05\xbc\0\0\x6d\x0e\0\0\x0f\0\0\0\0\0\0\0\x7f\x08\0\0\x49\x0a\0\0\
\x05\x14\x01\0\x10\0\0\0\x7f\x08\0\0\x3d\x09\0\0\x0e\x24\x01\0\x18\0\0\0\x7f\
\x08\0\0\x96\x0a\0\0\x38\x44\x01\0\x20\0\0\0\x7f\x08\0\0\x96\x0a\0\0\x02\x44\
\x01\0\x48\0\0\0\x7f\x08\0\0\xd9\x0a\0\0\x42\x50\x01\0\x50\0\0\0\x7f\x08\0\0\
\xd9\x0a\0\0\x0c\x50\x01\0\x78\0\0\0\x7f\x08\0\0\x23\x0b\0\0\x06\x58\x01\0\x80\
\0\0\0\x7f\x08\0\0\x32\x0b\0\0\x0f\x64\x01\0\x88\0\0\0\x7f\x08\0\0\x32\x0b\0\0\
\x06\x64\x01\0\x90\0\0\0\x7f\x08\0\0\x5e\x0b\0\0\x18\x68\x01\0\xb0\0\0\0\x7f\
\x08\0\0\x7b\x0b\0\0\x41\x70\x01\0\xb8\0\0\0\x7f\x08\0\0\x7b\x0b\0\0\x08\x70\
\x01\0\xd0\0\0\0\x7f\x08\0\0\xc5\x0b\0\0\x06\x74\x01\0\xd8\0\0\0\x7f\x08\0\0\
\xd0\x0b\0\0\x18\x78\x01\0\xf8\0\0\0\x7f\x08\0\0\x49\x0a\0\0\x05\x14\x01\0\x80\
\x0e\0\0\x10\0\0\0\0\0\0\0\x7f\x08\0\0\xee\x0b\0\0\x05\x90\x01\0\x08\0\0\0\x7f\
\x08\0\0\x3d\x09\0\0\x0e\x9c\x01\0\x10\0\0\0\x7f\x08\0\0\x6c\x09\0\0\x0d\xac\
\x01\0\x28\0\0\0\x7f\x08\0\0\x3d\x09\0\0\x29\x9c\x01\0\x30\0\0\0\x7f\x08\0\0\
\x6c\x09\0\0\x06\xac\x01\0\x38\0\0\0\x7f\x08\0\0\x37\x0c\0\0\x36\xb8\x01\0\x40\
\0\0\0\x7f\x08\0\0\x37\x0c\0\0\x0c\xb8\x01\0\x68\0\0\0\x7f\x08\0\0\x23\x0b\0\0\
\x06\xc0\x01\0\x70\0\0\0\x7f\x08\0\0\x32\x0b\0\0\x0f\xcc\x01\0\x78\0\0\0\x7f\
\x08\0\0\x32\x0b\0\0\x06\xcc\x01\0\x80\0\0\0\x7f\x08\0\0\x73\x0c\0\0\x15\xd0\
\x01\0\xa0\0\0\0\x7f\x08\0\0\x8d\x0c\0\0\x35\xd8\x01\0\xa8\0\0\0\x7f\x08\0\0\
\x8d\x0c\0\0\x08\xd8\x01\0\xc0\0\0\0\x7f\x08\0\0\xc5\x0b\0\0\x06\xdc\x01\0\xc8\
\0\0\0\x7f\x08\0\0\xc6\x0c\0\0\x15\xe0\x01\0\xe8\0\0\0\x7f\x08\0\0\xee\x0b\0\0\
\x05\x90\x01\0\x92\x0e\0\0\x0a\0\0\0\0\0\0\0\x7f\x08\0\0\xe1\x0c\0\0\x05\xf8\
\x01\0\x08\0\0\0\x7f\x08\0\0\x3d\x09\0\0\x0e\x04\x02\0\x10\0\0\0\x7f\x08\0\0\
\x6c\x09\0\0\x0d\x10\x02\0\x28\0\0\0\x7f\x08\0\0\x3d\x09\0\0\x29\x04\x02\0\x30\
\0\0\0\x7f\x08\0\0\x6c\x09\0\0\x06\x10\x02\0\x38\0\0\0\x7f\x08\0\0\x37\x0c\0\0\
\x36\x1c\x02\0\x40\0\0\0\x7f\x08\0\0\x37\x0c\0\0\x0c\x1c\x02\0\x68\0\0\0\x7f\
\x08\0\0\x23\x0b\0\0\x06\x24\x02\0\x78\0\0\0\x7f\x08\0\0\x2d\x0d\0\0\x11\x30\
\x02\0\x80\0\0\0\x7f\x08\0\0\xe1\x0c\0\0\x05\xf8\x01\0\xab\x0e\0\0\x11\0\0\0\0\
\0\0\0\x7f\x08\0\0\x54\x0d\0\0\x06\x54\x02\0\x08\0\0\0\x7f\x08\0\0\x3d\x09\0\0\
\x0e\x5c\x02\0\x10\0\0\0\x7f\x08\0\0\x6c\x09\0\0\x0d\x68\x02\0\x28\0\0\0\x7f\
\x08\0\0\x3d\x09\0\0\x29\x5c\x02\0\x30\0\0\0\x7f\x08\0\0\x6c\x09\0\0\x06\x68\
\x02\0\x38\0\0\0\x7f\x08\0\0\x83\x0d\0\0\x0c\x78\x02\0\x40\0\0\0\x7f\x08\0\0\
\xb5\x09\0\0\x0c\x74\x02\0\x70\0\0\0\x7f\x08\0\0\xad\x0d\0\0\x06\x80\x02\0\x80\
\0\0\0\x7f\x08\0\0\xbb\x0d\0\0\x1f\x84\x02\0\x88\0\0\0\x7f\x08\0\0\xbb\x0d\0\0\
\x25\x84\x02\0\x90\0\0\0\x7f\x08\0\0\xbb\x0d\0\0\x17\x84\x02\0\x98\0\0\0\x7f\
\x08\0\0\xe8\x0d\0\0\x3c\x8c\x02\0\xa0\0\0\0\x7f\x08\0\0\xe8\x0d\0\0\x42\x8c\
\x02\0\xa8\0\0\0\x7f\x08\0\0\xe8\x0d\0\0\x0c\x8c\x02\0\xd0\0\0\0\x7f\x08\0\0\
\x23\x0b\0\0\x06\x94\x02\0\xe0\0\0\0\x7f\x08\0\0\x2d\x0d\0\0\x11\xa0\x02\0\xe8\
\0\0\0\x7f\x08\0\0\x54\x0d\0\0\x06\x54\x02\0\x10\0\0\0\x5c\x0e\0\0\x01\0\0\0\
\x88\0\0\0\x1d\0\0\0\x32\x0e\0\0\0\0\0\0\x6d\x0e\0\0\x03\0\0\0\x18\0\0\0\x1d\0\
\0\0\x32\x0e\0\0\0\0\0\0\x48\0\0\0\x1d\0\0\0\x32\x0e\0\0\0\0\0\0\xb0\0\0\0\x1d\
\0\0\0\x32\x0e\0\0\0\0\0\0\x80\x0e\0\0\x02\0\0\0\x38\0\0\0\x57\0\0\0\x36\x0e\0\
\0\0\0\0\0\xa0\0\0\0\x57\0\0\0\x36\x0e\0\0\0\0\0\0\x92\x0e\0\0\x01\0\0\0\x38\0\
\0\0\x57\0\0\0\x36\x0e\0\0\0\0\0\0\xab\x0e\0\0\x04\0\0\0\x80\0\0\0\x65\0\0\0\
\x3a\x0e\0\0\0\0\0\0\x88\0\0\0\x6f\0\0\0\x3f\x0e\0\0\0\0\0\0\x98\0\0\0\x65\0\0\
\0\x3a\x0e\0\0\0\0\0\0\xa0\0\0\0\x6f\0\0\0\x3f\x0e\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x03\0\0\0\x20\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\x23\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x09\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\x68\x02\0\0\0\0\0\0\xb8\x02\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\
\x18\0\0\0\0\0\0\0\x11\0\0\0\x01\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x20\
\x05\0\0\0\0\0\0\xb8\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\x22\0\0\0\x01\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xd8\x05\0\0\0\0\0\
\0\x08\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x35\0\
\0\0\x01\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xe0\x06\0\0\0\0\0\0\xf8\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x47\0\0\0\x01\0\0\0\
\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xd8\x07\0\0\0\0\0\0\x90\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x60\0\0\0\x01\0\0\0\x06\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\x68\x08\0\0\0\0\0\0\xf0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x7b\0\0\0\x01\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\x58\x09\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x83\0\0\0\x08\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x5c\x09\
\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\x88\0\0\0\x01\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x5c\x09\0\0\0\0\0\0\
\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x8e\0\0\0\
\x01\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x68\x09\0\0\0\0\0\0\x60\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x97\x01\0\0\x09\0\0\0\
\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xc8\x09\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\x02\0\
\0\0\x03\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\xac\x01\0\0\x09\0\0\0\x40\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xe8\x09\0\0\0\0\0\0\x50\0\0\0\0\0\0\0\x02\0\0\0\
\x04\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\xc3\x01\0\0\x09\0\0\0\x40\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\x38\x0a\0\0\0\0\0\0\x50\0\0\0\0\0\0\0\x02\0\0\0\x05\0\
\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\xd9\x01\0\0\x09\0\0\0\x40\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\x88\x0a\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\x02\0\0\0\x06\0\0\0\
\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\xf6\x01\0\0\x09\0\0\0\x40\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\xa8\x0a\0\0\0\0\0\0\x30\0\0\0\0\0\0\0\x02\0\0\0\x07\0\0\0\x08\0\
\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x15\x02\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\xd8\x0a\0\0\0\0\0\0\x2e\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\x1a\x02\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\
\x2b\0\0\0\0\0\0\xec\x05\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0";
}

#endif /* __LOCAL_STORAGE_SKEL_H__ */
